use Test::More tests => 1;

BEGIN {
use_ok( 'HTML::KhatGallery::Plugin::SortNaturally' );
}

diag( "Testing HTML::KhatGallery::Plugin::SortNaturally ${HTML::KhatGallery::Plugin::SortNaturally::VERSION}" );
